@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2020 -- leonerd@leonerd.org.uk
 
-package Metrics::Any::Adapter::File;
+package Metrics::Any::Adapter::File 0.08;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.05';
-
 use Carp;
 
 =head1 NAME
